<?php
/**
 * Plugin Name: MiroRi Newsletter
 * Description: Veľmi jednoduchý plugin na správu a odosielanie newsletterov (noviniek)
 * Version: 1.4
 * Author: MiroR
 */

// Blokovanie priameho prístupu
if (!defined('ABSPATH')) {
    exit;
}

// Vytvorenie tabuľky pre e-maily pri aktivácii pluginu
function sn_create_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'newsletter_subscribers';
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        email varchar(255) NOT NULL,
        date_subscribed datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}
register_activation_hook(__FILE__, 'sn_create_table');

// Pridanie formulára na registráciu
require_once 'reg_form.php';

// Uloženie e-mailu do databázy
function sn_save_email($email) {
    if (!is_email($email)) {
        echo '<p style="color: red;">' . __('Neplatná e-mailová adresa.', 'mirori-newsletter') . '</p>';
        return;
    }

    global $wpdb;
    $table_name = $wpdb->prefix . 'newsletter_subscribers';

    if ($wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $table_name WHERE email = %s", $email)) > 0) {
        echo '<p style="color: red;">' . __('Tento e-mail je už zaregistrovaný.', 'mirori-newsletter') . '</p>';
        return;
    }

    $wpdb->insert(
        $table_name,
        ['email' => $email]
    );
    echo '<p style="color: green;">' . __('E-mail bol úspešne zaregistrovaný. Do 24hodín prebehne overenie administrátora. ', 'mirori-newsletter') . '</p>';

    // Odoslanie e-mailu administrátorovi
    $admin_email = get_option('admin_email');
    $subject = __('Nový odberateľ newsletteru', 'mirori-newsletter');
    $message = __('Nový odberateľ s e-mailom ', 'mirori-newsletter') . $email . __(' sa práve zaregistroval.', 'mirori-newsletter');
    $headers = array('Content-Type: text/html; charset=UTF-8');
    wp_mail($admin_email, $subject, $message, $headers);
}

// Pridanie stránky v administrácii pre správu odberateľov
function sn_admin_menu() {
    add_menu_page(
        __('Newsletter Admin', 'mirori-newsletter'),
        __('Newsletter Admin', 'mirori-newsletter'),
        'manage_options',
        'mirori-newsletter',
        'sn_admin_page'
    );
}
add_action('admin_menu', 'sn_admin_menu');

// Pridanie administrácie správy odberateľov
function sn_admin_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'newsletter_subscribers';
    $subscribers = $wpdb->get_results("SELECT * FROM $table_name");

    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'delete' && isset($_POST['id'])) {
        $id = intval($_POST['id']);
        $wpdb->delete($table_name, ['id' => $id]);
        echo '<div class="notice notice-success"><p>' . __('Odberateľ bol úspešne odstránený.', 'mirori-newsletter') . '</p></div>';
        $subscribers = $wpdb->get_results("SELECT * FROM $table_name"); // Refresh the list
    }
    ?>
    <div class="wrap">
        <h1><?php _e('Správa odberateľov', 'mirori-newsletter'); ?></h1>
        <p style="font-size: 18px;"><strong><?php _e('Poznámka:', 'mirori-newsletter'); ?></strong>
        <br><?php _e('Použite shortcode', 'mirori-newsletter'); ?> <code>[newsletter_form]</code> <?php _e('na zobrazenie formulára na stránkach,', 'mirori-newsletter'); ?>
        <br><?php _e('e-maily odosielaj cez menu Newsletter, Odoslať e-mail.', 'mirori-newsletter'); ?></p>
        <table class="widefat" style="table-layout: auto; width: 50%;">
            <thead>
                <tr>
                    <th style="width: 5%;"><?php _e('ID', 'mirori-newsletter'); ?></th>
                    <th style="width: 25%;"><?php _e('E-mail', 'mirori-newsletter'); ?></th>
                    <th style="width: 20%;"><?php _e('Dátum registrácie', 'mirori-newsletter'); ?></th>
                    <th style="width: 10%;"><?php _e('Akcia', 'mirori-newsletter'); ?></th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($subscribers as $subscriber): ?>
                    <tr>
                        <td><?php echo esc_html($subscriber->id); ?></td>
                        <td><?php echo esc_html($subscriber->email); ?></td>
                        <td><?php echo esc_html($subscriber->date_subscribed); ?></td>
                        <td>
                            <form method="post" style="display:inline;">
                                <input type="hidden" name="action" value="delete">
                                <input type="hidden" name="id" value="<?php echo esc_attr($subscriber->id); ?>">
                                <?php wp_nonce_field('sn_delete_nonce', 'sn_delete_nonce_field'); ?>
                                <button type="submit" class="button action"><?php _e('Odstrániť', 'mirori-newsletter'); ?></button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    <?php
}

// Funkcia na odosielanie newsletterov
function sn_send_newsletter($subject, $message) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'newsletter_subscribers';
    $subscribers = $wpdb->get_results("SELECT email FROM $table_name");

    foreach ($subscribers as $subscriber) {
        $unsubscribe_link = add_query_arg('unsubscribe', $subscriber->email, home_url('/'));
        $message .= '<br><br><a href="' . $unsubscribe_link . '">' . __('Zrušiť registráciu', 'mirori-newsletter') . '</a>';
        $headers = array('Content-Type: text/html; charset=UTF-8');
        wp_mail($subscriber->email, $subject, $message, $headers);
    }
}

// Pridanie stránky pre odosielanie e-mailov
function sn_send_email_page() {
    add_submenu_page(
        'mirori-newsletter',       // Slug hlavnej stránky
        __('Odoslať e-mail', 'mirori-newsletter'),          // Názov podstránky
        __('Odoslať e-mail', 'mirori-newsletter'),          // Názov v menu
        'manage_options',          // Oprávnenie
        'send-newsletter',         // Slug podstránky
        'sn_render_send_email_page' // Callback funkcia
    );
}
add_action('admin_menu', 'sn_send_email_page');

// Zobrazenie formulára na odoslanie e-mailu
require_once 'send_mail.php';

// Funkcia na zrušenie registrácie
function sn_unsubscribe() {
    if (isset($_GET['unsubscribe'])) {
        $email = sanitize_email($_GET['unsubscribe']);
        global $wpdb;
        $table_name = $wpdb->prefix . 'newsletter_subscribers';
        $wpdb->delete($table_name, ['email' => $email]);
        echo '<p>' . __('Vaša registrácia bola úspešne zrušená.', 'mirori-newsletter') . '</p>';
    }
}
add_action('init', 'sn_unsubscribe');

